@@ -36,7 +36,7 @@ class Multicall:
             - 'mainnet'
             - 'kovan'
             - 'rinkeby'
-            - 'gorli'
+            - 'goerli'
             - 'ropsten'
             - 'xdai'
             - 'polygon'
